pub struct Parser { /* private fields */ }Implementations
Sourceimpl Parser
impl Parser
Sourcepub fn from_html(html: String) -> Result<Parser, Error>
pub fn from_html(html: String) -> Result<Parser, Error>
Parses the provided HTML into a DOM document prepared for Microformats parsing.
Errors
This function will return an error if the HTML could not be parsed.
Sourcepub fn with_hook(self, hook: Arc<dyn ParserHook>) -> Parser
pub fn with_hook(self, hook: Arc<dyn ParserHook>) -> Parser
Sets a custom hook for the parser.
Sourcepub fn with_id_generation(self, enable: bool) -> Parser
pub fn with_id_generation(self, enable: bool) -> Parser
Enables or disables ID generation for AST elements.
Sourcepub fn into_document(
&mut self,
base_url: Option<Url>,
) -> Result<Document, Error>
pub fn into_document( &mut self, base_url: Option<Url>, ) -> Result<Document, Error>
With the loaded DOM in memory, parses it into a structured document.
Errors
This function will return an error if the DOM could not be parsed, relations could not be expanded or if items could not be expanded.
Sourcepub fn to_html(&self) -> Result<String, Error>
pub fn to_html(&self) -> Result<String, Error>
Generates HTML from the current AST, including any added attributes like data-mf2-id.
Errors
This function will return an error if HTML generation fails.
Sourcepub fn builder() -> ParserBuilder
pub fn builder() -> ParserBuilder
Creates a builder for constructing a Parser with custom options.